Learn R Programming

eRTG3D (version 0.7.0)

is.sf.3d: Tests if the object is a simple feature collection (class: 'sf, data.frame')

Description

Tests if the object is a simple feature collection (class: 'sf, data.frame')

Usage

is.sf.3d(track)

Arguments

track

any object to test

Value

A logical: TRUE if is a simple feature collection (class: 'sf, data.frame') of the sf package, FALSE otherwise.

Examples

Run this code
# NOT RUN {
is.sf.3d(niclas)
is.sf.3d(track2sf.3d(track = niclas, CRS = 2056))
# }

Run the code above in your browser using DataLab