Learn R Programming

eRTG3D (version 0.7.0)

lift2target.3d: Lift angle to target

Description

Calculates the lift angle between every point in the track and the last point (target).

Usage

lift2target.3d(track)

Arguments

track

a track data.frame containing x, y and z coordinates

Value

A numeric vector with the lift angles to target

Examples

Run this code
# NOT RUN {
lift2target.3d(niclas)
# }

Run the code above in your browser using DataLab