Learn R Programming

eRTG3D (version 0.7.0)

dem2track.extent: Crops the DEM to the extent of the track with a buffer

Description

Crops the DEM to the extent of the track with a buffer

Usage

dem2track.extent(DEM, track, buffer = 100)

Arguments

DEM

a raster containing a digital elevation model, covering the extent as the track

track

data.frame with x,y,z coordinates of the original track

buffer

buffer with, by default set to 100

Value

A the cropped digital elevation model as a raster layer.

Examples

Run this code
# NOT RUN {
dem2track.extent(dem, niclas)
# }

Run the code above in your browser using DataLab