powered by
Crops the DEM to the extent of the track with a buffer
dem2track.extent(DEM, track, buffer = 100)
a raster containing a digital elevation model, covering the extent as the track
data.frame with x,y,z coordinates of the original track
buffer with, by default set to 100
A the cropped digital elevation model as a raster layer.
# NOT RUN { dem2track.extent(dem, niclas) # }
Run the code above in your browser using DataLab