Learn R Programming

eRTG3D (version 0.7.0)

dist2point.3d: Distance of each track point to a given point

Description

Distance of each track point to a given point

Usage

dist2point.3d(track, point, groundDistance = FALSE)

Arguments

track

a list containing data.frames with x,y,z coordinates or a data.frame

point

a vector with x, y or x, y, z coordinates

groundDistance

logical: calculate only ground distance in x-y plane?

Value

Returns the distance of each track point to the point.

Examples

Run this code
# NOT RUN {
dist2point.3d(niclas, c(0, 0, 0))
# }

Run the code above in your browser using DataLab