powered by
Distance of each track point to a given point
dist2point.3d(track, point, groundDistance = FALSE)
a list containing data.frames with x,y,z coordinates or a data.frame
a vector with x, y or x, y, z coordinates
logical: calculate only ground distance in x-y plane?
Returns the distance of each track point to the point.
# NOT RUN { dist2point.3d(niclas, c(0, 0, 0)) # }
Run the code above in your browser using DataLab