Calculates the ratio between horizontal movement and vertical movement.
The value expresses the distance covered forward movement per distance movement in sinking.
Usage
get.glideRatio.3d(track)
Arguments
track
a track data.frame containing x, y and z coordinates of a gliding section
Value
The ratio between horizontal and vertical movement.