Learn R Programming

eRTG3D (version 0.7.0)

get.track.densities.3d: Extract tldCube and autodifferences functions from a consistent track

Description

Get densities creates a list consisting of the 3 dimensional probability distribution cube for turning angle, lift angle and step length (turnLiftStepHist) as well as the uni-dimensional distributions of the differences of the turning angles, lift angles and step lengths with a lag of 1 to maintain minimal level of autocorrelation in each of the terms.

Usage

get.track.densities.3d(
  track,
  gradientDensity = TRUE,
  heightDistEllipsoid = TRUE,
  DEM = NULL,
  maxBin = 25
)

Arguments

track

a data.frame with 3 columns containing the x,y,z coordinates

gradientDensity

logical: Should a distribution of the gradient angle be extracted and later used in the simulations?

heightDistEllipsoid

logical: Should a distribution of the flight height over ellipsoid be extracted and later used in the sim.cond.3d()?

DEM

a raster containing a digital elevation model, covering the same extent as the track

maxBin

numeric scalar, maximum number of bins per dimension of the tld-cube (turnLiftStepHist)

Value

A list containing the tldCube and the autodifferences functions (and additionally the height distribution function)

Examples

Run this code
# NOT RUN {
get.track.densities.3d(niclas, heightDist = TRUE)
# }

Run the code above in your browser using DataLab