powered by
Calculates the lift angle between every point in the track and the last point (target).
lift2target.3d(track)
a track data.frame containing x, y and z coordinates
A numeric vector with the lift angles to target
# NOT RUN { lift2target.3d(niclas) # }
Run the code above in your browser using DataLab