Simulates n tracks with the geometrical properties of the original track, between the same start and end point.
reproduce.track.3d(
track,
n.sim = 1,
parallel = FALSE,
error = TRUE,
DEM = NULL,
BG = NULL,
filterDeadEnds = TRUE,
plot2d = FALSE,
plot3d = FALSE,
maxBin = 25,
gradientDensity = TRUE
)data.frame with x,y,z coordinates of the original track
number of simulations that should be done
logical: run computations in parallel (n-1 cores)? Or numeric: the number of nodes (maximum: n - 1 cores)
logical: add error term to movement in simulation?
a raster containing a digital elevation model, covering the same extent as the track
a raster influencing the probabilities.
logical: Remove tracks that ended in a dead end?
logical: plot tracks on 2-D plane?
logical: plot tracks in 3-D?
numeric scalar, maximum number of bins per dimension of the tld-cube (turnLiftStepHist)
logical: Should a distribution of the gradient angle be extracted and used in the simulations (get.densities.3d)?
A list or data.frame containing the simulated track(s) (CERW).
# NOT RUN {
reproduce.track.3d(niclas[1:10, ])
# }
Run the code above in your browser using DataLab